from libxmp import XMPFiles
from libxmp import consts
import sys


def main():
    args = sys.argv[1:]
    print(args)
    data = {
        'filepath': args[0],
        'fcdfilename': args[1]
    }

    xmpfile = XMPFiles(file_path=data['filepath'], open_forupdate=True)
    xmp = xmpfile.get_xmp()

    for key, value in data.items():
        xmp.set_property(consts.XMP_NS_XMP, key, value)

    print(xmp)

    if xmpfile.can_put_xmp(xmp):
        xmpfile.put_xmp(xmp)
        xmpfile.close_file()
    else:
        xmpfile.close_file()





from setuptools import setup, find_packages

with open('requirements.txt') as f:
    requirements = f.readlines()

long_description = 'Package for adding custom xmp to Image Carriers'

setup(
    name='sgsxmp',
    version='1.2.0',
    author='Andrew Neary',
    author_email='andrew.neary@sgsco.com',
    description='Add xmp to Image Carriers',
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='SGS',
    packages=find_packages(),
    entry_points={
        'console_scripts': ['sgsxmp = sgsxmp.sgsxmp:main']
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent'
    ],
    keywords='sgsxmp',
    install_requires=requirements,
    zip_safe=False
)